@@ -1,3 +1,5 @@
+# coding=UTF-8
+
 import os
 import re
 import subprocess
@@ -186,3 +188,23 @@ def test_binary_tiddler():
     stored_tiddler = STORE.get(stored_tiddler)
     assert stored_tiddler.type == 'application/binary'
     assert stored_tiddler.text == 'lorem ipsum'
+
+
+def test_unicode_strings():
+    store_root = os.path.join(TMPDIR, 'test_store')
+
+    name = u'lorem ipsum – dolor sit amet' # ndash
+
+    bag = Bag(name)
+    tiddler = Tiddler(name, bag.name)
+    tiddler.text = name
+
+    # must not raise UnicodeDecodeError
+    STORE.put(bag)
+    STORE.put(tiddler)
+
+    tid = Tiddler(tiddler.title, bag.name)
+    tid = STORE.get(tid)
+    assert tid.bag == name
+    assert tid.title == name
+    assert tid.text == name
